@@ -47,7 +47,7 @@
  ** 									     ** 
  ** ************************************************************************ **/
 
-static char Id[] = "@(#)$Id: cmdVersion.c,v 1.9.16.2 2009/07/30 18:03:21 rkowen Exp $";
+static char Id[] = "@(#)$Id: cmdVersion.c,v 1.9.18.3 2010/10/02 21:05:01 rkowen Exp $";
 static void *UseId[] = { &UseId, Id };
 
 /** ************************************************************************ **/
@@ -295,8 +295,9 @@ int	cmdModuleVersion(	ClientData	 client_data,
     
     for( i=2; i<argc; i++) {
 
-	if( FindName( (char *) argv[ i], modptr->name, &tmp)) {
-	    if( OK != ErrorLogger( ERR_DUP_SYMVERS, LOC, argv[ i], NULL))
+	if( strcmp(argv[i], _default)
+	&&  FindName( (char *) argv[i], modptr->name, &tmp)) {
+	    if( OK != ErrorLogger( ERR_DUP_SYMVERS, LOC, argv[i], NULL))
 		break;
 	    else
 		continue;
@@ -456,7 +457,8 @@ static	char	*scan_versions( char		 *buffer,
 	if( mayloop != NULL ) {
 	    if( mayloop == base || *(mayloop-1) == ':' ) {
 		if( *(mayloop + strlen(ptr->name)) == ':' ) {
-	    	    ErrorLogger( ERR_SYMLOOP, LOC, ptr->name, NULL);
+		    if (strcmp(ptr->name,_default))
+	    		ErrorLogger( ERR_SYMLOOP, LOC, ptr->name, NULL);
 		    return((char *) NULL);	/** ---- EXIT (FAILURE) ---> **/
 		}
 	    }
