@@ -129,6 +129,13 @@ typedef	int	intptr_h;
 extern	int	  errno;
 #endif
 
+#ifdef HAVE_ASSERT_H
+#  include <assert.h>
+#else
+#  warning "not able to test code assertions"
+#  define assert(condition)
+#endif
+
 /** ************************************************************************ **/
 /** 				  LOCAL DATATYPES			     **/
 /** ************************************************************************ **/
@@ -555,6 +562,7 @@ extern	char	*instpath;
 extern	char	*rc_file;
 extern	char	*modulerc_file;
 extern	char	*version_file;
+extern	char	*change_dir;
 
 extern	char	 long_header[];
 
@@ -676,6 +684,9 @@ extern	void	  xresourceFinish( int);
 extern	int	  cmdModuleUser(ClientData, Tcl_Interp*, int, CONST84 char*[]);
 extern	int	  cmdModuleUser_sub( char *user_level);
 
+/**  cmdChdir.c **/
+extern	int	  cmdChDir(ClientData, Tcl_Interp*, int, CONST84 char*[]);
+
 /**  cmdLog.c  **/
 extern	int	  cmdModuleLog( ClientData, Tcl_Interp*, int, CONST84 char*[]);
 
@@ -726,6 +737,7 @@ extern	char	 *xstrtok_r(char *, const char *, char **);
 extern	char	 *xstrtok(char *, const char *);
 extern	void	  chk4spch( char*);
 extern	void	  cleanse_path( const char*, char*, int);
+extern	void	 *module_malloc(size_t);
 extern	char	 *xdup(char const *);
 extern	char	 *xgetenv(char const *);
 extern  int       tmpfile_mod( char**, FILE**);
