@@ -52,7 +52,7 @@
  ** 									     ** 
  ** ************************************************************************ **/
 
-static char Id[] = "@(#)$Id: utility.c,v 1.19.2.6.12.2 2009/07/30 18:03:21 rkowen Exp $";
+static char Id[] = "@(#)$Id: utility.c,v 1.19.4.2 2010/09/27 23:25:10 rkowen Exp $";
 static void *UseId[] = { &UseId, Id };
 
 /** ************************************************************************ **/
@@ -159,6 +159,8 @@ static  void     EscapeShString(const char* in,
 				 char* out);
 static  void     EscapePerlString(const char* in,
 				 char* out);
+static  void     EscapeCmakeString(const char* in,
+				 char* out);
 
 
 /*++++
@@ -1130,6 +1132,16 @@ static	int	output_set_variable(	Tcl_Interp	*interp,
 			shell_cmd_separator);  
 		null_free((void *) &escaped);
 
+    /**
+     **  CMAKE
+     **/
+    } else if( !strcmp((char*) shell_derelict, "cmake")) {
+		char* escaped = stringer(NULL, strlen(val)*2+1,NULL);
+		EscapeCmakeString(val,escaped);
+		fprintf(stdout, "set(ENV{%s} \"%s\")%s", var, escaped,
+			shell_cmd_separator);
+		null_free((void *) &escaped);
+
     /**
      **  PYTHON
      **/
@@ -1206,6 +1218,8 @@ static	int	output_unset_variable( const char* var)
 	fprintf( stdout, "(setenv \"%s\" nil)\n", var);
     } else if( !strcmp( shell_derelict, "perl")) {
 	fprintf( stdout, "delete $ENV{'%s'}%s", var, shell_cmd_separator);  
+    } else if( !strcmp( shell_derelict, "cmake")) {
+	fprintf( stdout, "unset(ENV{%s})%s", var, shell_cmd_separator);  
     } else if( !strcmp( shell_derelict, "python")) {
       fprintf( stdout, "os.environ['%s'] = ''\ndel os.environ['%s']\n",var,var);
     } else if( !strcmp( shell_derelict, "scm")) {
@@ -2756,6 +2770,19 @@ void EscapePerlString(const char* in,
   *out = 0;
 }
 
+/* I think this needs a bunch of work --NJW */
+void EscapeCmakeString(const char* in,
+		     char* out) {
+  for(;*in;in++) {
+    if (*in == '\\'||
+	*in == '"') {
+      *out++ = '\\';
+    }
+    *out++ = *in;
+  }
+  *out = 0;
+}
+
 /*++++
  ** ** Function-Header ***************************************************** **
  ** 									     **
